package org.plezervikt.allinone.fragments;

import android.app.Activity;
import android.app.ListFragment;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;

import org.plezervikt.allinone.R;
import org.plezervikt.allinone.gui.BookAdapter;
import org.plezervikt.allinone.models.Book;
import org.plezervikt.allinone.net.BookListDownloader;

import java.util.ArrayList;

/**
 * Created by coelho on 2014.11.17..
 */
public class BookListFragment extends ListFragment implements BookListDownloader.BookListDownloaderInterface {

    public interface BookListFragmentCallbacks {
        void bookSelected(Book book);
    }

    private BookListFragmentCallbacks callbacks;
    private ArrayList<Book> books;
    private BookListDownloader downloader;

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
        try {
            callbacks = (BookListFragmentCallbacks) activity;
        } catch (ClassCastException ccex) {
            throw new RuntimeException("AFragment's parent Activity must implement the AFragmentCallbacks interface");
        }
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        if(savedInstanceState != null) {
            books = (ArrayList<Book>) savedInstanceState.getSerializable("BOOKS");
            if(books != null) {
                BookAdapter adapter = new BookAdapter(getActivity(), books);
                setListAdapter(adapter);
            }
        }
    }

    @Override
    public void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);

        outState.putSerializable("BOOKS", books);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        return inflater.inflate(R.layout.fragment_booklist, container, false);
    }

    @Override
    public void onStart() {
        super.onStart();

        if(books == null) {
            downloader = new BookListDownloader(this);
            downloader.execute("http://coelho.d-lan.hu/gfmwa/books.json");
        }
    }

    @Override
    public void onListItemClick(ListView l, View v, int position, long id) {
        callbacks.bookSelected(books.get(position));
    }

    @Override
    public void booksAreDownloaded(ArrayList<Book> downloadedBooks) {
        downloader = null;
        if(getActivity() != null) {
            if(books == null) {
                books = downloadedBooks;
                BookAdapter adapter = new BookAdapter(getActivity(), books);
                setListAdapter(adapter);
            } else {
                books.addAll(downloadedBooks);
                ((BookAdapter)getListAdapter()).notifyDataSetChanged();
            }
        }
    }

    @Override
    public void bookDownloadingFailed() {
        downloader = null;
    }
}
