package org.plezervikt.allinone.net;

import android.os.AsyncTask;
import android.util.Log;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.plezervikt.allinone.models.Book;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;

/**
 * Created by coelho on 2014.11.17..
 */
public class BookListDownloader extends AsyncTask<String, Void, String> {

    public interface BookListDownloaderInterface {
        void booksAreDownloaded(ArrayList<Book> books);
        void bookDownloadingFailed();
    }

    private BookListDownloaderInterface listener;

    public BookListDownloader(BookListDownloaderInterface listener) {
        this.listener = listener;
    }

    @Override
    protected String doInBackground(String... strings) {
        if(strings.length == 0) return null;
        try {
            Log.d("ALLINONE", "DOWNLOADING");
            URL url = new URL(strings[0]);
            URLConnection connection = url.openConnection();
            InputStream stream = connection.getInputStream();
            String line = null;
            BufferedReader reader = new BufferedReader(new InputStreamReader(stream));
            StringBuilder builder = new StringBuilder();
            while((line = reader.readLine()) != null) {
                builder.append(line);
            }
            return builder.toString();
        } catch (MalformedURLException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return null;
    }

    @Override
    protected void onPostExecute(String s) {
        if(listener != null) {
            if(s == null) listener.bookDownloadingFailed();
            try {
                JSONObject object = new JSONObject(s);
                JSONArray errors = object.getJSONArray("errors");
                if(errors.length() != 0) listener.bookDownloadingFailed();
                else {
                    JSONObject data = object.getJSONObject("data");
                    JSONArray books = data.getJSONArray("books");
                    ArrayList<Book> results = new ArrayList<Book>();
                    for(int i = 0; i < books.length(); ++i) {
                        Book book = Book.parseFromJSON(books.getJSONObject(i));
                        results.add(book);
                    }
                    listener.booksAreDownloaded(results);
                }
            } catch (JSONException e) {
                listener.bookDownloadingFailed();
                return;
            }
        }
    }
}
